@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Nef_3/include/CGAL/Nef_3/Infimaximal_box.h $
-// $Id: Infimaximal_box.h e9d41d7 2020-04-21T10:03:00+02:00 Maxime Gimeno
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Nef_3/include/CGAL/Nef_3/Infimaximal_box.h $
+// $Id: include/CGAL/Nef_3/Infimaximal_box.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -24,6 +24,7 @@
 #include <CGAL/Extended_homogeneous.h>
 
 #include <CGAL/Nef_3/SNC_intersection.h>
+#include <CGAL/Nef_3/SNC_iteration.h>
 
 namespace CGAL {
 
@@ -151,7 +152,7 @@ class Infimaximal_box {
     create_vertices_on_infibox(SNC_constructor&,
                                const Plane_3&, const std::list<Point_3>&,
                                const Mark&, const Mark&, const Mark&) {
-    // TODO: warning oder assertion einbauen
+    // TODO: create warning or assertion
     return std::list<typename SNC_constructor::Vertex_handle>();
   }
 
@@ -401,9 +402,9 @@ class Infimaximal_box<Tag_true, Kernel> {
     typename SNC_structure::Vertex_const_iterator v;
     CGAL_forall_vertices(v, snc) {
       Point_3 p(v->point());
-      if(p.hx()[0] > eval) eval = p.hx()[0];
-      if(p.hy()[0] > eval) eval = p.hy()[0];
-      if(p.hz()[0] > eval) eval = p.hz()[0];
+      if(abs(p.hx()[0]) > eval) eval = abs(p.hx()[0]);
+      if(abs(p.hy()[0]) > eval) eval = abs(p.hy()[0]);
+      if(abs(p.hz()[0]) > eval) eval = abs(p.hz()[0]);
     }
     eval *= 4;
     if(eval == 0) return 1;
