@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Periodic_3_triangulation_3/include/CGAL/Periodic_3_regular_triangulation_3.h $
-// $Id: Periodic_3_regular_triangulation_3.h 98e4718 2021-08-26T11:33:39+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Periodic_3_triangulation_3/include/CGAL/Periodic_3_regular_triangulation_3.h $
+// $Id: include/CGAL/Periodic_3_regular_triangulation_3.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Monique Teillaud <Monique.Teillaud@inria.fr>
@@ -31,7 +31,6 @@
 #include <CGAL/spatial_sort.h>
 #include <CGAL/utility.h>
 
-#include <boost/mpl/if.hpp>
 #include <boost/mpl/identity.hpp>
 #include <boost/property_map/function_property_map.hpp>
 #include <boost/unordered_set.hpp>
@@ -177,11 +176,11 @@ private:
   };
 
   /// This threshold is chosen such that if all orthosphere radii are shorter
-  /// than this treshold, then we can be sure that there are no self-edges anymore.
+  /// than this threshold, then we can be sure that there are no self-edges anymore.
   FT orthosphere_radius_threshold;
 
   /// This container stores all the cells whose orthosphere radius is larger
-  /// than the treshold `orthosphere_radius_threshold`.
+  /// than the threshold `orthosphere_radius_threshold`.
   boost::unordered_set<Cell_handle, Cell_handle_hash> cells_with_too_big_orthoball;
 
   class Cover_manager
@@ -220,13 +219,20 @@ public:
   };
 
 public:
+  FT compute_cover_threshold() const
+  {
+    FT min_span = (std::min)({ domain().xmax() - domain().xmin(),
+                               domain().ymax() - domain().ymin(),
+                               domain().zmax() - domain().zmin() });
+    return FT(0.015625) * CGAL::square(min_span);
+  }
+
   /** @name Creation */
   Periodic_3_regular_triangulation_3(const Iso_cuboid& domain = Iso_cuboid(0, 0, 0, 1, 1, 1),
                                      const Geometric_traits& gt = Geometric_traits())
     : Tr_Base(domain, gt)
   {
-    orthosphere_radius_threshold = FT(0.015625) * (domain.xmax() - domain.xmin())
-                                                * (domain.xmax() - domain.xmin());
+    orthosphere_radius_threshold = compute_cover_threshold();
   }
 
   template < typename InputIterator >
@@ -236,8 +242,7 @@ public:
                                      bool is_large_point_set = false)
     : Tr_Base(domain, gt)
   {
-    orthosphere_radius_threshold = FT(0.015625) * (domain.xmax() - domain.xmin())
-                                                * (domain.xmax() - domain.xmin());
+    orthosphere_radius_threshold = compute_cover_threshold();
 
     insert(first, last, is_large_point_set);
   }
@@ -250,8 +255,8 @@ public:
     if(!is_1_cover())
       insert_cells_with_too_big_orthoball(tr.cells_begin(), tr.cells_end());
 
-    CGAL_triangulation_expensive_postcondition(*this == tr);
-    CGAL_triangulation_expensive_postcondition(is_valid());
+    CGAL_expensive_postcondition(*this == tr);
+    CGAL_expensive_postcondition(is_valid());
   }
 
   Periodic_3_regular_triangulation_3 operator=(Periodic_3_regular_triangulation_3 tr)
@@ -269,7 +274,7 @@ public:
 
   void create_initial_triangulation()
   {
-    CGAL_triangulation_assertion( cells_with_too_big_orthoball.empty() );
+    CGAL_assertion( cells_with_too_big_orthoball.empty() );
 
     for(Cell_iterator iter = cells_begin(), end_iter = cells_end(); iter != end_iter; ++iter)
       cells_with_too_big_orthoball.insert(iter);
@@ -383,8 +388,7 @@ public:
 
   virtual void update_cover_data_after_setting_domain ()
   {
-    orthosphere_radius_threshold = FT(0.015625) * (domain().xmax() - domain().xmin())
-                                                * (domain().xmax() - domain().xmin());
+    orthosphere_radius_threshold = compute_cover_threshold();
   }
 
   // the function below is used in `convert_to_1_sheeted_covering()` of P3T3
@@ -412,8 +416,8 @@ public:
     Conflict_tester tester(point, this);
     Point_hider hider(this);
     Cover_manager cover_manager(*this);
-    CGAL_triangulation_precondition(point.weight() >= 0);
-    CGAL_triangulation_precondition_msg
+    CGAL_precondition(point.weight() >= 0);
+    CGAL_precondition_msg
     (
       point.weight() < orthosphere_radius_threshold ,
      "point.weight() < 1/64 * domain_size * domain_size"
@@ -428,8 +432,8 @@ public:
     Conflict_tester tester(point, this);
     Point_hider hider(this);
     Cover_manager cover_manager(*this);
-    CGAL_triangulation_precondition(point.weight() >= 0);
-    CGAL_triangulation_precondition_msg
+    CGAL_precondition(point.weight() >= 0);
+    CGAL_precondition_msg
     (
       point.weight() < orthosphere_radius_threshold,
       "point.weight() < 1/64 * domain_size * domain_size"
@@ -444,7 +448,7 @@ public:
     if(first == last)
       return 0;
 
-    CGAL_triangulation_precondition_code
+    CGAL_precondition_code
     (
       bool precondition_is_satisfied = true;
       for(InputIterator pc_first = first, pc_last = last; pc_first != pc_last; ++pc_first)
@@ -457,7 +461,7 @@ public:
       }
     )
 
-    CGAL_triangulation_precondition_msg
+    CGAL_precondition_msg
     (
       precondition_is_satisfied,
       "0 <= point.weight() < 1/64 * domain_size * domain_size"
@@ -555,7 +559,7 @@ public:
       insert(*hi);
     }
 
-    CGAL_triangulation_expensive_postcondition(is_valid());
+    CGAL_expensive_postcondition(is_valid());
   }
 
   // Undocumented function that tries to remove 'v' but only does so if removal
@@ -563,7 +567,7 @@ public:
   // \pre the triangulation is 1-sheeted
   bool remove_if_no_cover_change(Vertex_handle v)
   {
-    CGAL_triangulation_precondition(this->is_1_cover());
+    CGAL_precondition(this->is_1_cover());
 
     // Since we are in a 1-sheet configuration, we can call directly periodic_remove()
     // and don't need the conflict tester. The rest is copied from above.
@@ -591,8 +595,8 @@ public:
       insert(*hi);
     }
 
-    CGAL_triangulation_expensive_postcondition(is_valid());
-    CGAL_triangulation_postcondition(this->is_1_cover());
+    CGAL_expensive_postcondition(is_valid());
+    CGAL_postcondition(this->is_1_cover());
     return true; // successfully removed the vertex
   }
 
@@ -609,6 +613,8 @@ public:
     return geom_traits().compare_power_distance_3_object()(p, q, r, o1, o2, o3) == SMALLER;
   }
 
+  // @fixme the overloads with offset might run into an issue if the intermediate construction
+  // does not preserve the orientation... See Robust_periodic_weighted_circumcenter_traits_3.h
   Bare_point construct_weighted_circumcenter(const Weighted_point &p, const Weighted_point &q,
                                              const Weighted_point &r) const
   {
@@ -648,7 +654,7 @@ public:
   Oriented_side power_side_of_oriented_power_sphere(const Weighted_point &p,
                                                     const Weighted_point &q) const
   {
-    CGAL_triangulation_precondition(this->equal(p, q));
+    CGAL_precondition(this->equal(p, q));
     return geom_traits().power_side_of_oriented_power_sphere_3_object()(p, q);
   }
   Oriented_side power_side_of_oriented_power_sphere(const Weighted_point &p, const Weighted_point &q,
@@ -700,7 +706,7 @@ public:
     const Offset& o3 = this->get_offset(c,3);
     const Offset& oq = offset;
 
-    CGAL_triangulation_precondition( orientation(p0, p1, p2, p3, o0, o1, o2, o3) == POSITIVE );
+    CGAL_precondition( orientation(p0, p1, p2, p3, o0, o1, o2, o3) == POSITIVE );
 
     Oriented_side os = ON_NEGATIVE_SIDE;
     os = power_side_of_oriented_power_sphere(p0, p1, p2, p3, q, o0, o1, o2, o3, oq);
@@ -721,7 +727,7 @@ public:
     // of the determinant has non null coefficient.
     for(int i=4; i>1; --i) {
       if(points[i] == &pts[4]) {
-        CGAL_triangulation_assertion(orientation(p0, p1, p2, p3, o0, o1, o2, o3)
+        CGAL_assertion(orientation(p0, p1, p2, p3, o0, o1, o2, o3)
             == POSITIVE);
         // since p0 p1 p2 p3 are non coplanar and positively oriented
         return ON_UNBOUNDED_SIDE;
@@ -745,7 +751,7 @@ public:
       }
     }
 
-    CGAL_triangulation_assertion(false);
+    CGAL_assertion(false);
     return ON_UNBOUNDED_SIDE;
   }
 
@@ -802,12 +808,12 @@ public:
     CGAL_precondition(CGAL::abs(move.z()) < domain().zmax() - domain().zmin() );
 
     // 'new_position' must be canonical
-    CGAL_triangulation_precondition(new_position.x() < domain().xmax());
-    CGAL_triangulation_precondition(new_position.y() < domain().ymax());
-    CGAL_triangulation_precondition(new_position.z() < domain().zmax());
-    CGAL_triangulation_precondition(new_position.x() >= domain().xmin());
-    CGAL_triangulation_precondition(new_position.y() >= domain().ymin());
-    CGAL_triangulation_precondition(new_position.z() >= domain().zmin());
+    CGAL_precondition(new_position.x() < domain().xmax());
+    CGAL_precondition(new_position.y() < domain().ymax());
+    CGAL_precondition(new_position.z() < domain().zmax());
+    CGAL_precondition(new_position.x() >= domain().xmin());
+    CGAL_precondition(new_position.y() >= domain().ymin());
+    CGAL_precondition(new_position.z() >= domain().zmin());
 
     if(new_position == v->point())
       return;
@@ -902,7 +908,7 @@ public:
       std::cout << "four offsets: " << std::endl;
 #endif
 
-      boost::array<int, 4> offsets;
+      std::array<int, 4> offsets;
       for(int i=0; i<4; ++i)
       {
 #ifdef CGAL_PERIODIC_SET_POINT_VERBOSE
@@ -925,7 +931,7 @@ public:
 
         CGAL_assertion(this->int_to_off(offsets[i])[0] == 0 || this->int_to_off(offsets[i])[0] == 1);
         CGAL_assertion(this->int_to_off(offsets[i])[1] == 0 || this->int_to_off(offsets[i])[1] == 1);
-        CGAL_assertion(this->int_to_off(offsets[i])[1] == 0 || this->int_to_off(offsets[i])[1] == 1);
+        CGAL_assertion(this->int_to_off(offsets[i])[2] == 0 || this->int_to_off(offsets[i])[2] == 1);
       }
 
       c->set_offsets(offsets[0], offsets[1], offsets[2], offsets[3]);
@@ -936,9 +942,9 @@ public:
     std::cout << "moved v to " << v->point() << std::endl;
 #endif
 
-    CGAL_triangulation_precondition(!(v->point().x() < domain().xmin()) && v->point().x() < domain().xmax());
-    CGAL_triangulation_precondition(!(v->point().y() < domain().ymin()) && v->point().y() < domain().ymax());
-    CGAL_triangulation_precondition(!(v->point().z() < domain().zmin()) && v->point().z() < domain().zmax());
+    CGAL_precondition(!(v->point().x() < domain().xmin()) && v->point().x() < domain().xmax());
+    CGAL_precondition(!(v->point().y() < domain().ymin()) && v->point().y() < domain().ymax());
+    CGAL_precondition(!(v->point().z() < domain().zmin()) && v->point().z() < domain().zmax());
   }
 
   Weighted_point point(const Periodic_weighted_point& pp) const
@@ -968,12 +974,12 @@ public:
 
   Vertex_handle nearest_power_vertex(const Bare_point& p, Cell_handle start) const
   {
-    CGAL_triangulation_precondition(p.x() < domain().xmax());
-    CGAL_triangulation_precondition(p.y() < domain().ymax());
-    CGAL_triangulation_precondition(p.z() < domain().zmax());
-    CGAL_triangulation_precondition(p.x() >= domain().xmin());
-    CGAL_triangulation_precondition(p.y() >= domain().ymin());
-    CGAL_triangulation_precondition(p.z() >= domain().zmin());
+    CGAL_precondition(p.x() < domain().xmax());
+    CGAL_precondition(p.y() < domain().ymax());
+    CGAL_precondition(p.z() < domain().zmax());
+    CGAL_precondition(p.x() >= domain().xmin());
+    CGAL_precondition(p.y() >= domain().ymin());
+    CGAL_precondition(p.z() >= domain().zmin());
 
     if(number_of_vertices() == 0)
       return Vertex_handle();
@@ -1067,7 +1073,7 @@ public:
 
   bool is_Gabriel(Cell_handle c, int i) const
   {
-    CGAL_triangulation_precondition(number_of_vertices() != 0);
+    CGAL_precondition(number_of_vertices() != 0);
     typename Geom_traits::Power_side_of_bounded_power_sphere_3
       side_of_bounded_power_sphere =
       geom_traits().power_side_of_bounded_power_sphere_3_object();
@@ -1102,7 +1108,7 @@ public:
 
   bool is_Gabriel(Cell_handle c, int i, int j) const
   {
-    CGAL_triangulation_precondition(number_of_vertices() != 0);
+    CGAL_precondition(number_of_vertices() != 0);
     typename Geom_traits::Power_side_of_bounded_power_sphere_3
       side_of_bounded_power_sphere =
       geom_traits().power_side_of_bounded_power_sphere_3_object();
@@ -1186,12 +1192,12 @@ public:
   // offsets to find the minimum
   Offset get_min_dist_offset_general(const Bare_point& p, const Vertex_handle vh) const
   {
-    CGAL_triangulation_precondition(p.x() < domain().xmax());
-    CGAL_triangulation_precondition(p.y() < domain().ymax());
-    CGAL_triangulation_precondition(p.z() < domain().zmax());
-    CGAL_triangulation_precondition(p.x() >= domain().xmin());
-    CGAL_triangulation_precondition(p.y() >= domain().ymin());
-    CGAL_triangulation_precondition(p.z() >= domain().zmin());
+    CGAL_precondition(p.x() < domain().xmax());
+    CGAL_precondition(p.y() < domain().ymax());
+    CGAL_precondition(p.z() < domain().zmax());
+    CGAL_precondition(p.x() >= domain().xmin());
+    CGAL_precondition(p.y() >= domain().ymin());
+    CGAL_precondition(p.z() >= domain().zmin());
 
     Offset min_off = Offset(0,0,0);
 
@@ -1215,7 +1221,7 @@ public:
   Vertex_handle nearest_vertex_in_cell(const Cell_handle& c,
                                        const Bare_point& p, const Offset & o) const
   {
-    CGAL_triangulation_precondition(number_of_vertices() != 0);
+    CGAL_precondition(number_of_vertices() != 0);
     Vertex_handle nearest = c->vertex(0);
     for(int i=1; i<4; i++)
     {
@@ -1384,7 +1390,7 @@ public:
                  OutputIteratorBoundaryFacets bfit, OutputIteratorCells cit,
                  OutputIteratorInternalFacets ifit) const
   {
-    CGAL_triangulation_precondition(number_of_vertices() != 0);
+    CGAL_precondition(number_of_vertices() != 0);
 
     std::vector<Facet> facets;
     facets.reserve(64);
@@ -1671,12 +1677,12 @@ public:
 
 //  inline void hide(Weighted_point&, Cell_handle ) const  // useless?
 //  {
-//    CGAL_triangulation_assertion(false);
+//    CGAL_assertion(false);
 //  }
 //
 //  inline void do_hide(const Weighted_point&, Cell_handle ) const // useless?
 //  {
-//    CGAL_triangulation_assertion(false);
+//    CGAL_assertion(false);
 //  }
 
 //  template < class Tester >
@@ -1746,16 +1752,14 @@ operator>> (std::istream& is, Periodic_3_regular_triangulation_3<GT, TDS>& tr)
 {
   typedef Periodic_3_regular_triangulation_3<GT,TDS>   P3RT3;
   typedef typename P3RT3::Tr_Base                      Tr_Base;
-  typedef typename GT::FT                              FT;
 
   is >> static_cast<Tr_Base&>(tr);
 
-  tr.orthosphere_radius_threshold = FT(0.015625) * (tr.domain().xmax() - tr.domain().xmin())
-                                                 * (tr.domain().xmax() - tr.domain().xmin());
+  tr.orthosphere_radius_threshold = tr.compute_cover_threshold();
 
   tr.insert_cells_with_too_big_orthoball(tr.cells_begin(), tr.cells_end());
 
-  CGAL_triangulation_expensive_assertion( tr.is_valid() );
+  CGAL_expensive_assertion( tr.is_valid() );
   return is;
 }
 
