@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/intersection.h $
-// $Id: intersection.h bb0b9a8 2022-03-07T15:32:37+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/intersection.h $
+// $Id: include/CGAL/Polygon_mesh_processing/intersection.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,25 +18,24 @@
 #include <CGAL/disable_warnings.h>
 
 #include <CGAL/AABB_face_graph_triangle_primitive.h>
-#include <CGAL/AABB_traits.h>
+#include <CGAL/AABB_traits_3.h>
 #include <CGAL/AABB_tree.h>
 #include <CGAL/boost/iterator/counting_iterator.hpp>
 #include <CGAL/box_intersection_d.h>
 #include <CGAL/Polygon_mesh_processing/internal/Corefinement/intersection_impl.h>
-#include <CGAL/Polygon_mesh_processing/internal/named_params_helper.h>
+#include <CGAL/boost/graph/named_params_helper.h>
 #include <CGAL/Polygon_mesh_processing/bbox.h>
 #include <CGAL/Polygon_mesh_processing/connected_components.h>
 #include <CGAL/Side_of_triangle_mesh.h>
 
+#include <boost/range/has_range_iterator.hpp>
 #include <boost/iterator/function_output_iterator.hpp>
-#include <boost/type_traits/is_same.hpp>
-#include <boost/utility/enable_if.hpp>
-#include <boost/mpl/if.hpp>
 
 #include <exception>
 #include <iterator>
 #include <utility>
 #include <vector>
+#include <type_traits>
 
 namespace CGAL {
 namespace Polygon_mesh_processing{
@@ -416,8 +415,8 @@ compute_face_face_intersection(const FaceRange& face_range1,
   // make one box per facet
   std::vector<Box> boxes1;
   std::vector<Box> boxes2;
-  boxes1.reserve(std::distance(boost::begin(face_range1), boost::end(face_range1)));
-  boxes2.reserve(std::distance(boost::begin(face_range2), boost::end(face_range2)));
+  boxes1.reserve(std::distance(std::begin(face_range1), std::end(face_range1)));
+  boxes2.reserve(std::distance(std::begin(face_range2), std::end(face_range2)));
 
   typedef typename GetVertexPointMap<TM, NamedParameters1>::const_type VertexPointMap1;
   typedef typename GetVertexPointMap<TM, NamedParameters2>::const_type VertexPointMap2;
@@ -426,8 +425,8 @@ compute_face_face_intersection(const FaceRange& face_range1,
                                         get_const_property_map(boost::vertex_point, tm1));
   VertexPointMap2 vpmap2 = choose_parameter(get_parameter(np2, internal_np::vertex_point),
                                         get_const_property_map(boost::vertex_point, tm2));
-  CGAL_static_assertion(
-      (boost::is_same<
+  static_assert(
+      (std::is_same<
        typename boost::property_traits<VertexPointMap1>::value_type,
        typename boost::property_traits<VertexPointMap2>::value_type
        >::value) );
@@ -544,12 +543,12 @@ compute_face_polyline_intersection(const FaceRange& face_range,
   VertexPointMap vpmap = choose_parameter(get_parameter(np, internal_np::vertex_point),
                                           get_const_property_map(boost::vertex_point, tm));
   typedef typename boost::property_traits<VertexPointMap>::value_type Point;
-  CGAL_static_assertion(
-        (boost::is_same<Point,
+  static_assert(
+        (std::is_same<Point,
         typename boost::range_value<Polyline>::type>::value));
 
   std::vector<face_descriptor> faces;
-  faces.reserve(std::distance(boost::begin(face_range), boost::end(face_range)));
+  faces.reserve(std::distance(std::begin(face_range), std::end(face_range)));
 
   typedef CGAL::Box_intersection_d::ID_FROM_BOX_ADDRESS Box_policy;
   typedef CGAL::Box_intersection_d::Box_with_info_d<double, 3, std::size_t, Box_policy> Box;
@@ -557,8 +556,8 @@ compute_face_polyline_intersection(const FaceRange& face_range,
   // make one box per facet
   std::vector<Box> boxes1;
   std::vector<Box> boxes2;
-  boxes1.reserve(std::distance(boost::begin(face_range), boost::end(face_range)));
-  boxes2.reserve(std::distance(boost::begin(polyline), boost::end(polyline)) - 1);
+  boxes1.reserve(std::distance(std::begin(face_range), std::end(face_range)));
+  boxes2.reserve(std::distance(std::begin(polyline), std::end(polyline)) - 1);
 
   for(face_descriptor f : face_range)
   {
@@ -682,10 +681,10 @@ compute_face_polylines_intersection(const FaceRange& face_range,
                                           get_const_property_map(boost::vertex_point, tm));
   typedef typename boost::property_traits<VertexPointMap>::value_type Point;
   typedef typename boost::range_value<PolylineRange>::type Polyline;
-  CGAL_static_assertion((boost::is_same<Point, typename boost::range_value<Polyline>::type>::value));
+  static_assert(std::is_same<Point, typename boost::range_value<Polyline>::type>::value);
 
   std::vector<face_descriptor> faces;
-  faces.reserve(std::distance( boost::begin(face_range), boost::end(face_range) ));
+  faces.reserve(std::distance( std::begin(face_range), std::end(face_range) ));
 
   typedef CGAL::Box_intersection_d::ID_FROM_BOX_ADDRESS Box_policy;
   typedef CGAL::Box_intersection_d::Box_with_info_d<double, 3, std::pair<std::size_t, std::size_t>, Box_policy> Box;
@@ -693,12 +692,12 @@ compute_face_polylines_intersection(const FaceRange& face_range,
   // make one box per facet
   std::vector<Box> boxes1;
   std::vector<Box> boxes2;
-  boxes1.reserve(std::distance(boost::begin(face_range), boost::end(face_range)));
+  boxes1.reserve(std::distance(std::begin(face_range), std::end(face_range)));
 
   std::size_t polylines_size = 0;
   for(Polyline poly : polyline_range)
   {
-    polylines_size += std::distance( boost::begin(poly), boost::end(poly) ) -1;
+    polylines_size += std::distance( std::begin(poly), std::end(poly) ) -1;
   }
   boxes2.reserve(polylines_size);
 
@@ -708,11 +707,11 @@ compute_face_polylines_intersection(const FaceRange& face_range,
     boxes1.push_back(Box(Polygon_mesh_processing::face_bbox(f, tm), std::make_pair(0, faces.size()-1)));
   }
 
-  std::size_t range_size = std::distance( boost::begin(polyline_range), boost::end(polyline_range) );
+  std::size_t range_size = std::distance( std::begin(polyline_range), std::end(polyline_range) );
   for(std::size_t j = 0; j < range_size; ++j)
   {
     Polyline poly = polyline_range[j];
-    std::size_t size = std::distance( boost::begin(poly), boost::end(poly) );
+    std::size_t size = std::distance( std::begin(poly), std::end(poly) );
     for(std::size_t i =0; i< size - 1; ++i)
     {
       Point p1 = poly[i];
@@ -786,8 +785,8 @@ compute_polyline_polyline_intersection(const Polyline& polyline1,
   // make one box per facet
   std::vector<Box> boxes1;
   std::vector<Box> boxes2;
-  boxes1.reserve(std::distance(boost::begin(polyline1), boost::end(polyline1)) - 1);
-  boxes2.reserve(std::distance(boost::begin(polyline2), boost::end(polyline2)) - 1);
+  boxes1.reserve(std::distance(std::begin(polyline1), std::end(polyline1)) - 1);
+  boxes2.reserve(std::distance(std::begin(polyline2), std::end(polyline2)) - 1);
 
   for(std::size_t i =0; i< polyline1.size()-1; ++i)
   {
@@ -871,7 +870,7 @@ compute_polylines_polylines_intersection(const PolylineRange& polylines1,
   CGAL::Bbox_3 b1, b2;
   for(Polyline poly : polylines1)
   {
-    polylines_size += std::distance( boost::begin(poly), boost::end(poly) ) -1;
+    polylines_size += std::distance( std::begin(poly), std::end(poly) ) -1;
     b1 += CGAL::bbox_3(poly.begin(), poly.end());
   }
   boxes1.reserve( polylines_size );
@@ -879,7 +878,7 @@ compute_polylines_polylines_intersection(const PolylineRange& polylines1,
   polylines_size = 0;
   for(Polyline poly : polylines2)
   {
-    polylines_size += std::distance( boost::begin(poly), boost::end(poly) ) -1;
+    polylines_size += std::distance( std::begin(poly), std::end(poly) ) -1;
     b2 += CGAL::bbox_3(poly.begin(), poly.end());
   }
   boxes2.reserve(polylines_size);
@@ -887,11 +886,11 @@ compute_polylines_polylines_intersection(const PolylineRange& polylines1,
   if(!CGAL::do_overlap(b1,b2))
     return out;
 
-  std::size_t range_size = std::distance( boost::begin(polylines1), boost::end(polylines1) );
+  std::size_t range_size = std::distance( std::begin(polylines1), std::end(polylines1) );
   for(std::size_t j = 0; j < range_size; ++j)
   {
     Polyline poly = polylines1[j];
-    std::size_t size = std::distance( boost::begin(poly), boost::end(poly) );
+    std::size_t size = std::distance( std::begin(poly), std::end(poly) );
     for(std::size_t i =0; i< size - 1; ++i)
     {
       const Point& p1 = poly[i];
@@ -900,11 +899,11 @@ compute_polylines_polylines_intersection(const PolylineRange& polylines1,
     }
   }
 
-  range_size = std::distance( boost::begin(polylines2), boost::end(polylines2) );
+  range_size = std::distance( std::begin(polylines2), std::end(polylines2) );
   for(std::size_t j = 0; j < range_size; ++j)
   {
     Polyline poly = polylines2[j];
-    std::size_t size = std::distance( boost::begin(poly), boost::end(poly) );
+    std::size_t size = std::distance( std::begin(poly), std::end(poly) );
     for(std::size_t i =0; i< size - 1; ++i)
     {
       const Point& p1 = poly[i];
@@ -1111,7 +1110,7 @@ bool is_mesh2_in_mesh1(const TriangleMesh& tm1,
                        const GT& gt)
 {
   typedef CGAL::AABB_face_graph_triangle_primitive<TriangleMesh, VPM1> Primitive;
-  typedef CGAL::AABB_traits<GT, Primitive> Traits;
+  typedef CGAL::AABB_traits_3<GT, Primitive> Traits;
   typedef CGAL::AABB_tree<Traits> AABBTree;
 
   AABBTree tree1(faces(tm1).begin(), faces(tm1).end(), tm1, vpm1);
@@ -1143,14 +1142,14 @@ template <class PolylineRange>
 bool do_intersect(const PolylineRange& polylines1,
                   const PolylineRange& polylines2
 #ifndef DOXYGEN_RUNNING
-                  , const typename boost::enable_if<
-                    typename boost::has_range_iterator<
+                  , const std::enable_if_t<
+                      boost::has_range_iterator<
                       typename boost::mpl::eval_if<
                         boost::has_range_iterator<PolylineRange>,
                         boost::range_value<PolylineRange>,
-                        boost::false_type >::type
-                    >::type
-                   >::type* = 0//end enable_if
+                        std::false_type >::type
+                    >::value
+                   >* = 0//end enable_if
 #endif
     )
 {
@@ -1187,18 +1186,18 @@ template <class Polyline>
 bool do_intersect(const Polyline& polyline1,
                   const Polyline& polyline2
 #ifndef DOXYGEN_RUNNING
-                , const typename boost::enable_if<
-                    typename boost::has_range_const_iterator<Polyline>::type
-                  >::type* = 0,
-                  const typename boost::disable_if<
-                    typename boost::has_range_iterator<
+                , const std::enable_if_t<
+                    boost::has_range_const_iterator<Polyline>::value
+                  >* = 0,
+                  const std::enable_if_t<
+                    !boost::has_range_iterator<
                       typename boost::mpl::eval_if<
                         boost::has_range_iterator<Polyline>,
                         boost::range_value<Polyline>,
-                        boost::false_type
+                        std::false_type
                       >::type
-                    >::type
-                  >::type* = 0//end enable_if
+                    >::value
+                  >* = 0//end enable_if
 #endif
                  )
 {
@@ -1275,9 +1274,9 @@ bool do_intersect(const TriangleMesh& tm1,
                   const CGAL_NP_CLASS_1& np1 = parameters::default_values(),
                   const CGAL_NP_CLASS_2& np2 = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-                  , const typename boost::disable_if<
-                                    typename boost::has_range_const_iterator<TriangleMesh>::type
-                  >::type* = 0
+                  , const std::enable_if_t<
+                            !boost::has_range_const_iterator<TriangleMesh>::value
+                  >* = 0
 #endif
                   )
 {
@@ -1361,15 +1360,15 @@ bool do_intersect(const TriangleMesh& tm,
                   const PolylineRange& polylines,
                   const NamedParameters& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-                , const typename boost::enable_if<
-                    typename boost::has_range_iterator<
+                , const std::enable_if_t<
+                    boost::has_range_iterator<
                       typename boost::mpl::eval_if<
                         boost::has_range_iterator<PolylineRange>,
                         boost::range_value<PolylineRange>,
-                        boost::false_type
+                        std::false_type
                       >::type
-                    >::type
-                  >::type* = 0//end enable_if
+                    >::value
+                  >* = 0//end enable_if
 #endif
                  )
 {
@@ -1428,19 +1427,17 @@ bool do_intersect(const TriangleMesh& tm,
                   const Polyline& polyline,
                   const CGAL_NP_CLASS& np = parameters::default_values()
 #ifndef DOXYGEN_RUNNING
-                , const typename boost::disable_if<
-                    typename boost::mpl::or_<
-                      typename boost::is_same<TriangleMesh, Polyline>::type, // Added to please MSVC 2015
-                      typename boost::mpl::not_<typename boost::has_range_iterator<Polyline>::type>::type, // not a range
-                      typename boost::has_range_iterator<
+                , const std::enable_if_t<!(
+                      std::is_same_v<TriangleMesh, Polyline> || // Added to please MSVC 2015
+                      !boost::has_range_iterator<Polyline>::value || // not a range
+                      boost::has_range_iterator<
                         typename boost::mpl::eval_if<
                           boost::has_range_iterator<Polyline>,
                           boost::range_value<Polyline>,
-                          boost::false_type
-                        >::type
-                      >::type // not a range of a range
-                    >::type
-                  >::type* = 0
+                          std::false_type>::type
+                        >::value
+                    )
+                  >* = 0
 #endif
                  )
 {
@@ -1468,7 +1465,7 @@ struct Mesh_callback
   typedef typename boost::range_value<NamedParametersRange>::type NamedParameters;
   typedef typename GetVertexPointMap<TriangleMesh, NamedParameters>::const_type VPM;
   typedef CGAL::AABB_face_graph_triangle_primitive<TriangleMesh, VPM> Primitive;
-  typedef CGAL::AABB_traits<GT, Primitive> Traits;
+  typedef CGAL::AABB_traits_3<GT, Primitive> Traits;
   typedef CGAL::AABB_tree<Traits> AABBTree;
   typedef typename boost::graph_traits<TriangleMesh>::face_descriptor face_descriptor;
 
@@ -1576,7 +1573,7 @@ struct Mesh_callback
  *
  * detects and reports all the pairs of meshes intersecting in a range of triangulated surface meshes.
  * A pair of meshes intersecting is put in the output iterator `out` as a `std::pair<std::size_t, std::size_t>`,
- * each index refering to the index of the triangle mesh in the input range.
+ * each index referring to the index of the triangle mesh in the input range.
  * If `do_overlap_test_of_bounded_sides` is `true`, the overlap of bounded sides are tested as well. In that case, the meshes must be closed.
  * This function depends on the package \ref PkgBoxIntersectionD.
  *
@@ -1715,7 +1712,7 @@ OutputIterator intersecting_meshes(const TriangleMeshRange& range,
  *   \cgalParamNEnd
  *
  *   \cgalParamNBegin{throw_on_self_intersection}
- *     \cgalParamDescription{If `true`, the set of triangles closed to the intersection of `tm1` and `tm2` will be
+ *     \cgalParamDescription{If `true`, the set of triangles close to the intersection of `tm1` and `tm2` will be
  *                           checked for self-intersections and `Corefinement::Self_intersection_exception`
  *                           will be thrown if at least one self-intersection is found.}
  *     \cgalParamType{Boolean}
@@ -1743,8 +1740,8 @@ surface_intersection(const TriangleMesh& tm1,
   typedef typename GetVertexPointMap<TriangleMesh, NamedParameters1>::const_type VPM1;
   typedef typename GetVertexPointMap<TriangleMesh, NamedParameters2>::const_type VPM2;
 
-  CGAL_static_assertion((std::is_same<typename boost::property_traits<VPM1>::value_type,
-                                      typename boost::property_traits<VPM2>::value_type>::value));
+  static_assert(std::is_same<typename boost::property_traits<VPM1>::value_type,
+                                      typename boost::property_traits<VPM2>::value_type>::value);
 
   VPM1 vpm1 = parameters::choose_parameter(parameters::get_parameter(np1, internal_np::vertex_point),
                                            get_const_property_map(CGAL::vertex_point, tm1));
