@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/measure.h $
-// $Id: measure.h 763c5e9 2022-03-30T08:05:20+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Polygon_mesh_processing/include/CGAL/Polygon_mesh_processing/measure.h $
+// $Id: include/CGAL/Polygon_mesh_processing/measure.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -22,8 +22,10 @@
 #include <CGAL/boost/graph/helpers.h>
 #include <CGAL/boost/graph/properties.h>
 #include <CGAL/Named_function_parameters.h>
-#include <CGAL/Polygon_mesh_processing/internal/named_params_helper.h>
+#include <CGAL/boost/graph/named_params_helper.h>
 
+#include <CGAL/Polygon_mesh_processing/border.h>
+#include <CGAL/utils_classes.h>
 
 #include <CGAL/Lazy.h> // needed for CGAL::exact(FT)/CGAL::exact(Lazy_exact_nt<T>)
 
@@ -31,6 +33,7 @@
 #include <boost/graph/graph_traits.hpp>
 #include <boost/dynamic_bitset.hpp>
 
+#include <vector>
 #include <utility>
 #include <algorithm>
 #include <unordered_set>
@@ -112,7 +115,7 @@ edge_length(typename boost::graph_traits<PolygonMesh>::halfedge_descriptor h,
   using parameters::choose_parameter;
   using parameters::get_parameter;
 
-  CGAL_precondition(boost::graph_traits<PolygonMesh>::null_halfedge() != h);
+  CGAL_precondition(is_valid_halfedge_descriptor(h, pmesh));
 
   typename GetVertexPointMap<PolygonMesh, NamedParameters>::const_type
       vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
@@ -132,6 +135,8 @@ edge_length(typename boost::graph_traits<PolygonMesh>::edge_descriptor e,
             const PolygonMesh& pmesh,
             const NamedParameters& np = parameters::default_values())
 {
+  CGAL_precondition(is_valid_edge_descriptor(e, pmesh));
+
   return edge_length(halfedge(e, pmesh), pmesh, np);
 }
 
@@ -187,7 +192,7 @@ squared_edge_length(typename boost::graph_traits<PolygonMesh>::halfedge_descript
   using parameters::choose_parameter;
   using parameters::get_parameter;
 
-  CGAL_precondition(boost::graph_traits<PolygonMesh>::null_halfedge() != h);
+  CGAL_precondition(is_valid_halfedge_descriptor(h, pmesh));
 
   typename GetVertexPointMap<PolygonMesh, NamedParameters>::const_type
       vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
@@ -208,9 +213,30 @@ squared_edge_length(typename boost::graph_traits<PolygonMesh>::edge_descriptor e
                     const PolygonMesh& pmesh,
                     const NamedParameters& np = parameters::default_values())
 {
+  CGAL_precondition(is_valid_edge_descriptor(e, pmesh));
+
   return squared_edge_length(halfedge(e, pmesh), pmesh, np);
 }
 
+template<typename PolygonMesh,
+         typename NamedParameters = parameters::Default_named_parameters>
+typename GetGeomTraits<PolygonMesh, NamedParameters>::type::FT
+average_edge_length(const PolygonMesh& pmesh,
+                    const NamedParameters& np = parameters::default_values())
+{
+  typedef typename GetGeomTraits<PolygonMesh, NamedParameters>::type GT;
+
+  const std::size_t n = edges(pmesh).size();
+  CGAL_assertion(n > 0);
+
+  typename GT::FT avg_edge_length = 0;
+  for (auto e : edges(pmesh))
+    avg_edge_length += edge_length(e, pmesh, np);
+
+  avg_edge_length /= static_cast<typename GT::FT>(n);
+  return avg_edge_length;
+}
+
 /**
   * \ingroup PMP_measure_grp
   *
@@ -261,12 +287,14 @@ face_border_length(typename boost::graph_traits<PolygonMesh>::halfedge_descripto
                    const PolygonMesh& pmesh,
                    const NamedParameters& np = parameters::default_values())
 {
-  typename GetGeomTraits<PolygonMesh, NamedParameters>::type::FT result = 0;
+  using FT = typename GetGeomTraits<PolygonMesh, NamedParameters>::type::FT;
+  ::CGAL::internal::Evaluate<FT> evaluate;
+  FT result = 0;
 
   for(typename boost::graph_traits<PolygonMesh>::halfedge_descriptor haf : halfedges_around_face(h, pmesh))
   {
     result += edge_length(haf, pmesh, np);
-    exact(result);
+    evaluate(result);
   }
 
   return result;
@@ -304,6 +332,7 @@ face_border_length(typename boost::graph_traits<PolygonMesh>::halfedge_descripto
   *   - `first`: a halfedge on the longest border.
   *     The return type `halfedge_descriptor` is a halfedge descriptor. It is
   *     deduced from the graph traits corresponding to the type `PolygonMesh`.
+  *     `first` is among the halfedges reported by `extract_boundary_cycles()`.
   *   - `second`: the length of the longest border
   *     The return type `FT` is a number type either deduced from the `geom_traits`
   *     \ref bgl_namedparameters "Named Parameters" if provided,
@@ -314,6 +343,7 @@ face_border_length(typename boost::graph_traits<PolygonMesh>::halfedge_descripto
   * will be performed approximately.
   *
   * @see `face_border_length()`
+  * @see `extract_boundary_cycles()`
   */
 template<typename PolygonMesh,
          typename NamedParameters = parameters::Default_named_parameters>
@@ -330,28 +360,18 @@ longest_border(const PolygonMesh& pmesh,
             typename property_map_value<PolygonMesh, CGAL::vertex_point_t>::type>::Kernel::FT  FT;
   typedef typename boost::graph_traits<PolygonMesh>::halfedge_descriptor                       halfedge_descriptor;
 
-  std::unordered_set<halfedge_descriptor> visited;
+  std::vector<halfedge_descriptor> boundary_cycles;
+  extract_boundary_cycles(pmesh, std::back_inserter(boundary_cycles));
   halfedge_descriptor result_halfedge = boost::graph_traits<PolygonMesh>::null_halfedge();
   FT result_len = 0;
-  for(halfedge_descriptor h : halfedges(pmesh))
+  for(halfedge_descriptor h : boundary_cycles)
   {
-    if(visited.find(h)== visited.end())
-    {
-      if(is_border(h, pmesh))
-      {
-        FT len = 0;
-        for(halfedge_descriptor haf : halfedges_around_face(h, pmesh))
-        {
-          len += edge_length(haf, pmesh, np);
-          visited.insert(haf);
-        }
+    FT len = face_border_length(h, pmesh, np);
 
-        if(result_len < len)
-        {
-          result_len = len;
-          result_halfedge = h;
-        }
-      }
+    if(result_len < len)
+    {
+      result_len = len;
+      result_halfedge = h;
     }
   }
   return std::make_pair(result_halfedge, result_len);
@@ -415,7 +435,7 @@ face_area(typename boost::graph_traits<TriangleMesh>::face_descriptor f,
 
   typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor halfedge_descriptor;
 
-  CGAL_precondition(boost::graph_traits<TriangleMesh>::null_face() != f);
+  CGAL_precondition(is_valid_face_descriptor(f, tmesh));
 
   typename GetVertexPointMap<TriangleMesh, CGAL_NP_CLASS>::const_type
       vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
@@ -486,7 +506,7 @@ squared_face_area(typename boost::graph_traits<TriangleMesh>::face_descriptor f,
 
   typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor halfedge_descriptor;
 
-  CGAL_precondition(boost::graph_traits<TriangleMesh>::null_face() != f);
+  CGAL_precondition(is_valid_face_descriptor(f, tmesh));
 
   typename GetVertexPointMap<TriangleMesh, CGAL_NP_CLASS>::const_type
       vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
@@ -559,11 +579,14 @@ area(FaceRange face_range,
 {
   typedef typename boost::graph_traits<TriangleMesh>::face_descriptor face_descriptor;
 
-  typename GetGeomTraits<TriangleMesh, CGAL_NP_CLASS>::type::FT result = 0;
+  using FT = typename GetGeomTraits<TriangleMesh, CGAL_NP_CLASS>::type::FT;
+  FT result = 0;
+  ::CGAL::internal::Evaluate<FT> evaluate;
+
   for(face_descriptor f : face_range)
   {
     result += face_area(f, tmesh, np);
-    exact(result);
+    evaluate(result);
   }
 
   return result;
@@ -676,7 +699,10 @@ volume(const TriangleMesh& tmesh,
 
   typedef typename boost::graph_traits<TriangleMesh>::face_descriptor face_descriptor;
 
-  typename GetGeomTraits<TriangleMesh, CGAL_NP_CLASS>::type::FT volume = 0;
+  using FT = typename GetGeomTraits<TriangleMesh, CGAL_NP_CLASS>::type::FT;
+  ::CGAL::internal::Evaluate<FT> evaluate;
+
+  FT volume = 0;
   typename CGAL::Kernel_traits<typename property_map_value<TriangleMesh,
       CGAL::vertex_point_t>::type>::Kernel::Compute_volume_3 cv3;
 
@@ -686,7 +712,7 @@ volume(const TriangleMesh& tmesh,
                   get(vpm, target(halfedge(f, tmesh), tmesh)),
                   get(vpm, target(next(halfedge(f, tmesh), tmesh), tmesh)),
                   get(vpm, target(prev(halfedge(f, tmesh), tmesh), tmesh)));
-    exact(volume);
+    evaluate(volume);
   }
 
   return volume;
@@ -741,7 +767,7 @@ face_aspect_ratio(typename boost::graph_traits<TriangleMesh>::face_descriptor f,
                   const TriangleMesh& tmesh,
                   const CGAL_NP_CLASS& np = parameters::default_values())
 {
-  CGAL_precondition(f != boost::graph_traits<TriangleMesh>::null_face());
+  CGAL_precondition(is_valid_face_descriptor(f, tmesh));
   CGAL_precondition(is_triangle(halfedge(f, tmesh), tmesh));
 
   typedef typename boost::graph_traits<TriangleMesh>::halfedge_descriptor           halfedge_descriptor;
@@ -859,39 +885,46 @@ centroid(const TriangleMesh& tmesh,
   Vpm vpm = choose_parameter(get_parameter(np, internal_np::vertex_point),
                              get_const_property_map(CGAL::vertex_point, tmesh));
 
-  typedef typename GetGeomTraits<TriangleMesh, CGAL_NP_CLASS>::type Kernel;
-  typedef typename Kernel::Point_3                                      Point_3;
+  typedef typename GetGeomTraits<TriangleMesh, CGAL_NP_CLASS>::type     Kernel;
+  Kernel k = choose_parameter<Kernel>(get_parameter(np, internal_np::geom_traits));
+
+  typedef typename Kernel::FT                                           FT;
+  typedef typename boost::property_traits<Vpm>::reference               Point_3_ref;
   typedef typename Kernel::Vector_3                                     Vector_3;
+
   typedef typename Kernel::Construct_translated_point_3                 Construct_translated_point_3;
   typedef typename Kernel::Construct_vector_3                           Construct_vector_3;
   typedef typename Kernel::Construct_normal_3                           Construct_normal_3;
   typedef typename Kernel::Compute_scalar_product_3                     Scalar_product;
   typedef typename Kernel::Construct_scaled_vector_3                    Scale;
   typedef typename Kernel::Construct_sum_of_vectors_3                   Sum;
+
   typedef typename boost::graph_traits<TriangleMesh>::face_descriptor   face_descriptor;
-  typedef typename Kernel::FT FT;
 
   FT volume = 0;
 
   Vector_3 centroid(NULL_VECTOR);
 
-  Construct_translated_point_3 point;
-  Construct_vector_3 vector;
-  Construct_normal_3 normal;
-  Scalar_product scalar_product;
-  Scale scale;
-  Sum sum;
+  Construct_translated_point_3 point = k.construct_translated_point_3_object();
+  Construct_vector_3 vector = k.construct_vector_3_object();
+  Construct_normal_3 normal = k.construct_normal_3_object();
+  Scalar_product scalar_product = k.compute_scalar_product_3_object();
+  Scale scale = k.construct_scaled_vector_3_object();
+  Sum sum = k.construct_sum_of_vectors_3_object();
+
+  ::CGAL::internal::Evaluate<FT> evaluate;
 
   for(face_descriptor fd : faces(tmesh))
   {
-    const Point_3& p = get(vpm, target(halfedge(fd, tmesh), tmesh));
-    const Point_3& q = get(vpm, target(next(halfedge(fd, tmesh), tmesh), tmesh));
-    const Point_3& r = get(vpm, target(prev(halfedge(fd, tmesh), tmesh), tmesh));
+    const Point_3_ref p = get(vpm, target(halfedge(fd, tmesh), tmesh));
+    const Point_3_ref q = get(vpm, target(next(halfedge(fd, tmesh), tmesh), tmesh));
+    const Point_3_ref r = get(vpm, target(prev(halfedge(fd, tmesh), tmesh), tmesh));
     Vector_3 vp = vector(ORIGIN, p),
              vq = vector(ORIGIN, q),
              vr = vector(ORIGIN, r);
     Vector_3 n = normal(p, q, r);
     volume += (scalar_product(n,vp))/FT(6);
+    evaluate(volume);
     n = scale(n, FT(1)/FT(24));
 
     Vector_3 v2 = sum(vp, vq);
@@ -902,6 +935,7 @@ centroid(const TriangleMesh& tmesh,
     v3 = sum(v3, Vector_3(square(v2.x()), square(v2.y()), square(v2.z())));
 
     centroid = sum(centroid, Vector_3(n.x() * v3.x(), n.y() * v3.y(), n.z() * v3.z()));
+    evaluate(centroid);
   }
 
   centroid = scale(centroid, FT(1)/(FT(2)*volume));
@@ -987,8 +1021,8 @@ void match_faces(const PolygonMesh1& m1,
                                        get_const_property_map(vertex_point, m1));
   const VPMap2 vpm2 = choose_parameter(get_parameter(np2, internal_np::vertex_point),
                                        get_const_property_map(vertex_point, m2));
-  CGAL_static_assertion_msg((boost::is_same<typename boost::property_traits<VPMap1>::value_type,
-                             typename boost::property_traits<VPMap2>::value_type>::value),
+  static_assert(std::is_same<typename boost::property_traits<VPMap1>::value_type,
+                             typename boost::property_traits<VPMap2>::value_type>::value,
                             "Both vertex point maps must have the same point type.");
 
   const VIMap1 vim1 = get_initialized_vertex_index_map(m1, np1);
