@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Visibility_2/include/CGAL/Triangular_expansion_visibility_2.h $
-// $Id: Triangular_expansion_visibility_2.h 1faa0e2 2021-04-28T10:55:26+02:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Visibility_2/include/CGAL/Triangular_expansion_visibility_2.h $
+// $Id: include/CGAL/Triangular_expansion_visibility_2.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -21,7 +21,6 @@
 #include <memory>
 #include <CGAL/boost/iterator/transform_iterator.hpp>
 #include <CGAL/Constrained_Delaunay_triangulation_2.h>
-#include <CGAL/Arr_observer.h>
 #include <CGAL/assertions.h>
 #include <CGAL/use.h>
 
@@ -86,63 +85,83 @@ private:
   };
 
   // Observer to track any changes of the attached arrangement.
-  class Observer : public Arr_observer<Arrangement_2>
+  class Observer : public Arrangement_2::Observer
   {
-
-      typedef Arr_observer<Arrangement_2>                           Base;
-      typedef Observer                                              Self;
-
+      using Base = typename Arrangement_2::Observer;
+      using Self = Observer;
 
   public:
+      using Base_aos = typename Arrangement_2::Base_aos;
+      using Vertex_handle = typename Base_aos::Vertex_handle;
+      using Halfedge_handle = typename Base_aos::Halfedge_handle;
+      using Face_handle = typename Base_aos::Face_handle;
+      using Ccb_halfedge_circulator = typename Base_aos::Ccb_halfedge_circulator;
+
       bool has_changed;
 
-      Observer() : Base(), has_changed(false)
+      Observer() : Base(), has_changed(false) {}
+
+      Observer(const Base_aos& arr) :
+        Base(const_cast<Base_aos&>(arr)), has_changed(false)
       {}
 
-      Observer(const Arrangement_2& arr)
-          : Base(const_cast<Arrangement_2&>(arr)), has_changed(false)
-      {}
+      // Aos_observer interface
 
-      // Arr_observer interface
+      virtual void after_attach() override { has_changed = false; }
 
-      void after_attach() { has_changed = false; }
-
-
-      void after_global_change() { has_changed = true; }
-      void after_create_vertex(Vertex_handle) { has_changed = true; }
-      void after_create_boundary_vertex(Vertex_handle) { has_changed = true; }
-      void after_create_edge(Halfedge_handle) { has_changed = true; }
-      void after_modify_vertex(Vertex_handle) { has_changed = true; }
-      void after_modify_edge(Halfedge_handle) { has_changed = true; }
-      void after_split_edge(Halfedge_handle, Halfedge_handle) {
-          has_changed = true; }
-      void after_split_fictitious_edge(Halfedge_handle, Halfedge_handle) {
-          has_changed = true; }
-      void after_split_face(Face_handle, Face_handle, bool) {
-          has_changed = true; }
-      void after_split_outer_ccb(Face_handle, Ccb_halfedge_circulator,
-                                 Ccb_halfedge_circulator) {
-          has_changed = true; }
-      void after_split_inner_ccb(Face_handle, Ccb_halfedge_circulator,
-                                 Ccb_halfedge_circulator) {
-          has_changed = true; }
-      void after_add_outer_ccb(Ccb_halfedge_circulator) { has_changed = true; }
-      void after_add_inner_ccb(Ccb_halfedge_circulator) { has_changed = true; }
-      void after_add_isolated_vertex(Vertex_handle) { has_changed = true; }
-      void after_merge_edge(Halfedge_handle) { has_changed = true; }
-      void after_merge_fictitious_edge(Halfedge_handle) { has_changed = true; }
-      void after_merge_face(Face_handle) { has_changed = true; }
-      void after_merge_outer_ccb(Face_handle, Ccb_halfedge_circulator) {
-          has_changed = true; }
-      void after_merge_inner_ccb(Face_handle, Ccb_halfedge_circulator) {
-          has_changed = true; }
-      void after_move_outer_ccb(Ccb_halfedge_circulator) { has_changed = true; }
-      void after_move_inner_ccb(Ccb_halfedge_circulator) { has_changed = true; }
-      void after_move_isolated_vertex(Vertex_handle) { has_changed = true; }
-      void after_remove_vertex() { has_changed = true; }
-      void after_remove_edge() { has_changed = true; }
-      void after_remove_outer_ccb(Face_handle) { has_changed = true; }
-      void after_remove_inner_ccb(Face_handle) { has_changed = true; }
+      virtual void after_global_change() override { has_changed = true; }
+      virtual void after_create_vertex(Vertex_handle) override
+      { has_changed = true; }
+      virtual void after_create_boundary_vertex(Vertex_handle) override
+      { has_changed = true; }
+      virtual void after_create_edge(Halfedge_handle) override
+      { has_changed = true; }
+      virtual void after_modify_vertex(Vertex_handle) override
+      { has_changed = true; }
+      virtual void after_modify_edge(Halfedge_handle) override
+      { has_changed = true; }
+      virtual void after_split_edge(Halfedge_handle, Halfedge_handle) override
+      { has_changed = true; }
+      virtual void after_split_fictitious_edge(Halfedge_handle, Halfedge_handle)
+        override
+      { has_changed = true; }
+      virtual void after_split_face(Face_handle, Face_handle, bool) override
+      { has_changed = true; }
+      virtual void after_split_outer_ccb(Face_handle, Ccb_halfedge_circulator,
+                                         Ccb_halfedge_circulator) override
+      { has_changed = true; }
+      virtual void after_split_inner_ccb(Face_handle, Ccb_halfedge_circulator,
+                                         Ccb_halfedge_circulator) override
+      { has_changed = true; }
+      virtual void after_add_outer_ccb(Ccb_halfedge_circulator) override
+      { has_changed = true; }
+      virtual void after_add_inner_ccb(Ccb_halfedge_circulator) override
+      { has_changed = true; }
+      virtual void after_add_isolated_vertex(Vertex_handle) override
+      { has_changed = true; }
+      virtual void after_merge_edge(Halfedge_handle) override
+      { has_changed = true; }
+      virtual void after_merge_fictitious_edge(Halfedge_handle) override
+      { has_changed = true; }
+      virtual void after_merge_face(Face_handle) override { has_changed = true; }
+      virtual void after_merge_outer_ccb(Face_handle, Ccb_halfedge_circulator)
+        override
+      { has_changed = true; }
+      virtual void after_merge_inner_ccb(Face_handle, Ccb_halfedge_circulator)
+        override
+      { has_changed = true; }
+      virtual void after_move_outer_ccb(Ccb_halfedge_circulator) override
+      { has_changed = true; }
+      virtual void after_move_inner_ccb(Ccb_halfedge_circulator) override
+      { has_changed = true; }
+      virtual void after_move_isolated_vertex(Vertex_handle) override
+      { has_changed = true; }
+      virtual void after_remove_vertex() override { has_changed = true; }
+      virtual void after_remove_edge() override { has_changed = true; }
+      virtual void after_remove_outer_ccb(Face_handle) override
+      { has_changed = true; }
+      virtual void after_remove_inner_ccb(Face_handle) override
+      { has_changed = true; }
   };
 
 
@@ -481,7 +500,7 @@ private:
         //std::cout << vh->point() <<" -3- "<< nvh->point() <<std::endl;
         needles.push_back(Segment_2(vh->point(),nvh->point()));
       }
-      // but we may also contiue looking along the vertex
+      // but we may also continue looking along the vertex
       if(!p_cdt->is_constrained(re)) {
         collect_needle(q,nvh,nfh,rindex);
       }
@@ -564,7 +583,7 @@ private:
           //std::cout<< "h1 done"<< std::endl;
           return oit;
         }else{
-          // spliting at new vertex
+          // splitting at new vertex
           //std::cout<< "h2"<< std::endl;
           *oit++ = expand_edge(q,nvh->point(),right,nfh,rindex,oit);
           //std::cout<< "h2 done"<< std::endl;
@@ -581,7 +600,7 @@ private:
     //std::cout << "rvh->point()  "<< rvh->point() << std::endl<< std::endl;
 
 
-    // determin whether new vertex needs to be reported
+    // determine whether new vertex needs to be reported
     if(ro != CGAL::CLOCKWISE && lo != CGAL::COUNTERCLOCKWISE){
       *oit++ = nvh->point();
     }
@@ -601,7 +620,7 @@ private:
     if(lo == CGAL::CLOCKWISE){
       if(p_cdt->is_constrained(le)){
         // the edge is constrained
-        // report interesection with right boarder if exists
+        // report intersection with right boarder if exists
         if(ro == CGAL::CLOCKWISE){
           *oit++ = ray_seg_intersection(q,right,nvh->point(),lvh->point());
         }
@@ -620,7 +639,7 @@ private:
           //std::cout<< "h3 done"<< std::endl;
           return oit;
         }else{
-          // spliting at new vertex
+          // splitting at new vertex
           //std::cout<< "h4"<< std::endl;
           oit = expand_edge(q,left,nvh->point(),nfh,lindex,oit);
           //std::cout<< "h4 done"<< std::endl;
