@@ -2,8 +2,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Straight_skeleton_2/include/CGAL/predicates/Straight_skeleton_pred_ftC2.h $
-// $Id: Straight_skeleton_pred_ftC2.h c502e93 2020-11-27T13:53:59+01:00 Mael Rouxel-Labbé
+// $URL: https://github.com/CGAL/cgal/blob/v6.0.2/Straight_skeleton_2/include/CGAL/predicates/Straight_skeleton_pred_ftC2.h $
+// $Id: include/CGAL/predicates/Straight_skeleton_pred_ftC2.h e13ef800cb7 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Fernando Cacciola <fernando_cacciola@ciudad.com.ar>
@@ -23,8 +23,7 @@
 #include <CGAL/Quotient.h>
 #include <CGAL/Uncertain.h>
 
-#include <boost/optional/optional.hpp>
-#include <boost/intrusive_ptr.hpp>
+#include <optional>
 
 #include <stdexcept>
 
@@ -37,10 +36,9 @@ namespace CGAL_SS_i {
 // the three points are along the same line, in any order.
 template<class K>
 inline
-Uncertain<bool> certified_collinearC2( Point_2<K> const& p
-                                     , Point_2<K> const& q
-                                     , Point_2<K> const& r
-                                     )
+Uncertain<bool> certified_collinearC2( typename K::Point_2 const& p,
+                                       typename K::Point_2 const& q,
+                                       typename K::Point_2 const& r )
 {
   return CGAL_NTS certified_is_equal( ( q.x() - p.x() ) * ( r.y() - p.y() )
                                     , ( r.x() - p.x() ) * ( q.y() - p.y() )
@@ -52,10 +50,9 @@ Uncertain<bool> certified_collinearC2( Point_2<K> const& p
 // q is in the closed segment [p,r].
 template<class K>
 inline
-Uncertain<bool> certified_collinear_are_ordered_along_lineC2( Point_2<K> const& p
-                                                            , Point_2<K> const& q
-                                                            , Point_2<K> const& r
-                                                            )
+Uncertain<bool> certified_collinear_are_ordered_along_lineC2( typename K::Point_2 const& p,
+                                                              typename K::Point_2 const& q,
+                                                              typename K::Point_2 const& r )
 {
   if ( CGAL_NTS certainly(p.x() < q.x()) ) return !(r.x() < q.x());
   if ( CGAL_NTS certainly(q.x() < p.x()) ) return !(q.x() < r.x());
@@ -101,7 +98,7 @@ Uncertain<bool> are_parallel_edges_equally_orientedC2( Segment_2_with_ID<K> cons
 }
 
 
-// Returns true IFF segments e0,e1 share the same supporting line but do not overlap except at the vetices, and have the same orientation.
+// Returns true IFF segments e0,e1 share the same supporting line but do not overlap except at the vertices, and have the same orientation.
 // NOTE: If e1 goes back over e0 (a degenerate antenna or alley) this returns false.
 template<class K>
 Uncertain<bool> are_edges_orderly_collinearC2( Segment_2_with_ID<K> const& e0, Segment_2_with_ID<K> const& e1 )
@@ -116,50 +113,6 @@ Uncertain<Sign> certified_side_of_oriented_lineC2(const FT &a, const FT &b, cons
   return CGAL_NTS certified_sign(a*x+b*y+c);
 }
 
-
-//
-// Constructs a Trisegment_2 which stores 3 edges (segments) such that
-// if two of them are collinear, they are put first, as e0, e1.
-// Stores also the number of collinear edges. which should be 0 or 2.
-//
-// If the collinearity test is indeterminate for any pair of edges the
-// resulting sorted trisegment is itself indeterminate
-// (encoded as a collinear count of -1)
-//
-template<class K>
-Uncertain<Trisegment_collinearity> certified_trisegment_collinearity ( Segment_2_with_ID<K> const& e0
-                                                                     , Segment_2_with_ID<K> const& e1
-                                                                     , Segment_2_with_ID<K> const& e2
-                                                                     )
-{
-  Uncertain<bool> is_01 = are_edges_orderly_collinearC2(e0,e1);
-  if ( is_certain(is_01) )
-  {
-    Uncertain<bool> is_02 = are_edges_orderly_collinearC2(e0,e2);
-    if ( is_certain(is_02) )
-    {
-      Uncertain<bool> is_12 = are_edges_orderly_collinearC2(e1,e2);
-      if ( is_certain(is_12) )
-      {
-        if ( CGAL_NTS logical_and(is_01 , !is_02 , !is_12 ) )
-          return TRISEGMENT_COLLINEARITY_01;
-        else if ( CGAL_NTS logical_and(is_02 , !is_01 , !is_12 ) )
-          return TRISEGMENT_COLLINEARITY_02;
-        else if ( CGAL_NTS logical_and(is_12 , !is_01 , !is_02 ) )
-          return TRISEGMENT_COLLINEARITY_12;
-        else if ( CGAL_NTS logical_and(!is_01 , !is_02, !is_12  ) )
-          return TRISEGMENT_COLLINEARITY_NONE;
-        else
-          return TRISEGMENT_COLLINEARITY_ALL;
-      }
-    }
-  }
-
-  return Uncertain<Trisegment_collinearity>::indeterminate();
-}
-
-
-
 // Given 3 oriented straight line segments: e0, e1, e2
 // returns true if there exists some positive offset distance 't' for which the
 // leftward-offsets of their supporting lines intersect at a single point.
@@ -170,28 +123,30 @@ Uncertain<Trisegment_collinearity> certified_trisegment_collinearity ( Segment_2
 // is well defined, In that case, the degenerate vertex can be even a contour vertex or a skeleton node. If it is a skeleton
 // node, it is properly defined by the trisegment tree that corresponds to the node.
 // A trisegment tree stores not only the "current event" trisegment but also the trisegments for the left/right seed vertices,
-// recursivey in case the seed vertices are skeleton nodes as well.
+// recursively in case the seed vertices are skeleton nodes as well.
 // Those seeds are used to determine the actual position of the degenerate vertex in case of collinear edges (since that point is
 // not given by the collinear edges alone)
 //
-template<class K, class FT, class TimeCache, class CoeffCache>
-Uncertain<bool> exist_offset_lines_isec2 ( boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& tri,
-                                           boost::optional<FT> const& aMaxTime,
-                                           TimeCache& aTime_cache,
-                                           CoeffCache& aCoeff_cache )
+template<class K, class FT, class Caches>
+Uncertain<bool> exist_offset_lines_isec2 ( Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& tri,
+                                           std::optional<FT> const& aMaxTime,
+                                           Caches& aCaches )
 {
 
   typedef Rational<FT>              Rational ;
-  typedef boost::optional<Rational> Optional_rational ;
+  typedef std::optional<Rational> Optional_rational ;
   typedef Quotient<FT>              Quotient ;
 
   Uncertain<bool> rResult = Uncertain<bool>::indeterminate();
 
+  CGAL_STSKEL_TRAITS_TRACE( "\n~~ Checking existence of an event [" << typeid(FT).name() << "]");
+  CGAL_STSKEL_TRAITS_TRACE("Event:\n" << tri);
+
   if ( tri->collinearity() != TRISEGMENT_COLLINEARITY_ALL )
   {
     CGAL_STSKEL_TRAITS_TRACE( ( tri->collinearity() == TRISEGMENT_COLLINEARITY_NONE ? " normal edges" : " collinear edges" ) ) ;
 
-    Optional_rational t = compute_offset_lines_isec_timeC2(tri, aTime_cache, aCoeff_cache) ;
+    Optional_rational t = compute_offset_lines_isec_timeC2(tri, aCaches) ;
     if ( t )
     {
       Uncertain<bool> d_is_zero = CGAL_NTS certified_is_zero(t->d()) ;
@@ -206,25 +161,27 @@ Uncertain<bool> exist_offset_lines_isec2 ( boost::intrusive_ptr< Trisegment_2<K,
           if ( aMaxTime && CGAL_NTS certainly(rResult) )
             rResult = CGAL_NTS certified_is_smaller_or_equal(tq,Quotient(*aMaxTime));
 
-          CGAL_STSKEL_TRAITS_TRACE("\nEvent time: " << *t << ". Event " << ( rResult ? "exist." : "doesn't exist." ) ) ;
+          CGAL_STSKEL_TRAITS_TRACE("Event time: " << *t << ". Event " << ( rResult ? "exist." : "doesn't exist." ) ) ;
         }
         else
         {
-          CGAL_STSKEL_TRAITS_TRACE("\nDenominator exactly zero, Event doesn't exist." ) ;
+          CGAL_STSKEL_TRAITS_TRACE("Denominator exactly zero, Event doesn't exist." ) ;
           rResult = false;
         }
       }
-      else{
-        CGAL_STSKEL_TRAITS_TRACE("\nDenominator is probably zero (but not exactly), event existence is indeterminate." ) ;
+      else
+      {
+        CGAL_STSKEL_TRAITS_TRACE("Denominator is probably zero (but not exactly), event existence is indeterminate." ) ;
       }
     }
-    else{
-      CGAL_STSKEL_TRAITS_TRACE("\nEvent time overflowed, event existence is indeterminate." ) ;
+    else
+    {
+      CGAL_STSKEL_TRAITS_TRACE("Event time overflowed, event existence is indeterminate." ) ;
     }
   }
   else
   {
-    CGAL_STSKEL_TRAITS_TRACE("\nAll the edges are collinear. Event doesn't exist." ) ;
+    CGAL_STSKEL_TRAITS_TRACE("All the edges are collinear. Event doesn't exist." ) ;
     rResult = false;
   }
 
@@ -233,31 +190,33 @@ Uncertain<bool> exist_offset_lines_isec2 ( boost::intrusive_ptr< Trisegment_2<K,
 
 // Given 2 triples of oriented straight line segments: (m0,m1,m2) and (n0,n1,n2), such that
 // for each triple there exists distances 'mt' and 'nt' for which the offsets lines (at mt and nt resp.),
-// (m0',m1',m2') and (n0',n1',n2') intersect each in a single point; returns the relative order of mt w.r.t nt.
+// (m0',m1',m2') and (n0',n1',n2') intersect each in a single point; returns the relative order of mt w.r.t. nt.
 // That is, indicates which offset triple intersects first (closer to the source lines)
 // PRECONDITION: There exists distances mt and nt for which each offset triple intersect at a single point.
-template<class K, class TimeCache, class CoeffCache>
+template<class K, class Caches>
 Uncertain<Comparison_result>
-compare_offset_lines_isec_timesC2 ( boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& m,
-                                    boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& n,
-                                    TimeCache& aTime_cache,
-                                    CoeffCache& aCoeff_cache )
+compare_offset_lines_isec_timesC2 ( Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& m,
+                                    Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& n,
+                                    Caches& aCaches )
 {
   typedef typename K::FT FT ;
 
   typedef Rational<FT>       Rational ;
   typedef Quotient<FT>       Quotient ;
-  typedef boost::optional<Rational> Optional_rational ;
+  typedef std::optional<Rational> Optional_rational ;
+
+  CGAL_STSKEL_TRAITS_TRACE("compare_offset_lines_isec_timesC2(\n" << m << "\n" << n << "\n) [" << typeid(FT).name() << "]" );
 
   Uncertain<Comparison_result> rResult = Uncertain<Comparison_result>::indeterminate();
 
-  Optional_rational mt_ = compute_offset_lines_isec_timeC2(m, aTime_cache, aCoeff_cache);
-  Optional_rational nt_ = compute_offset_lines_isec_timeC2(n, aTime_cache, aCoeff_cache);
+  Optional_rational mt_ = compute_offset_lines_isec_timeC2(m, aCaches);
+  Optional_rational nt_ = compute_offset_lines_isec_timeC2(n, aCaches);
 
   if ( mt_ && nt_ )
   {
     Quotient mt = mt_->to_quotient();
     Quotient nt = nt_->to_quotient();
+
     if ( CGAL_NTS certified_is_positive(mt) && CGAL_NTS certified_is_positive(nt) )
       rResult = CGAL_NTS certified_compare(mt,nt);
   }
@@ -297,11 +256,10 @@ Uncertain<Comparison_result> compare_isec_anglesC2 ( Vector_2<K> const& aBV1
   return rResult;
 }
 
-
 // Returns true if the point aP is on the positive side of the line supporting the edge
 //
 template<class K>
-Uncertain<bool> is_edge_facing_pointC2 ( boost::optional< Point_2<K> > const& aP,
+Uncertain<bool> is_edge_facing_pointC2 ( std::optional< typename K::Point_2 > const& aP,
                                          Segment_2_with_ID<K> const& aEdge )
 {
   typedef typename K::FT FT ;
@@ -319,17 +277,17 @@ Uncertain<bool> is_edge_facing_pointC2 ( boost::optional< Point_2<K> > const& aP
 // Given a triple of oriented straight line segments: (e0,e1,e2) such that their offsets
 // at some distance intersects in a point (x,y), returns true if (x,y) is on the positive side of the line supporting aEdge
 //
-template<class K, class CoeffCache>
+template<class K, class Caches>
 inline Uncertain<bool>
-is_edge_facing_offset_lines_isecC2 ( boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& tri,
+is_edge_facing_offset_lines_isecC2 ( Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& tri,
                                      Segment_2_with_ID<K> const& aEdge,
-                                     CoeffCache& aCoeff_cache)
+                                     Caches& aCaches )
 {
-  return is_edge_facing_pointC2(construct_offset_lines_isecC2(tri, aCoeff_cache), aEdge);
+  return is_edge_facing_pointC2(construct_offset_lines_isecC2(tri, aCaches), aEdge);
 }
 
 // Given an event trisegment and two oriented straight line segments e0 and e1, returns the oriented side of the event point
-// w.r.t the (positive) bisector [e0,e1].
+// w.r.t. the (positive) bisector [e0,e1].
 //
 // The (positive) bisector [e0,e1] is a ray starting at the vertex (e0,e1) (called "v01")
 //
@@ -350,7 +308,7 @@ is_edge_facing_offset_lines_isecC2 ( boost::intrusive_ptr< Trisegment_2<K, Segme
 //
 // If e0,e1 are collinear then this perpendicular line is a perpendicular bisector of the two segments.
 //
-// If e0,e1 are parallel but not collinear then the actual bisector is an equidistant line parallel to e0 and e1.
+// If e0,e1 are parallel but in opposite directions then the bisector is an equidistant line parallel to e0 and e1.
 // e0* and e1* overlap and are known to be connected sharing a known vertex v01, which is somewhere along the parallel
 // line which is the bisector of e0 and e1.
 // Given a line perpendicular to e0 through v01, a point to its positive side belongs to e0* while a point to its negative side does not.
@@ -363,59 +321,62 @@ is_edge_facing_offset_lines_isecC2 ( boost::intrusive_ptr< Trisegment_2<K, Segme
 // Testing its validity amounts to determining if the split point is inside the closed offset segment instead of
 // the two open rays before and after the offset segment endpoints.
 // The offset edge is bounded by its previous and next adjacent edges at the time of the event. Thus, the bisectors
-// of this edge and its previous/next adjacent edges (at the time of the event) detemine the offset vertices that
+// of this edge and its previous/next adjacent edges (at the time of the event) determine the offset vertices that
 // bound the opposite edge.
 // If the opposite edge is 'e' and its previous/next edges are "preve"/"nexte" then the split point is inside the offset
 // edge if it is NOT to the positive side of [preve,e] *and* NOT to the negative side o [e,nexte].
-// (so this predicate answer half the question, at one and other side independenty).
-// If the split point is exacty over any of this bisectors then the split point ocurres exactly and one (or both) endpoints
-// of the opposite edge (so it is a pseudo-split event since the opposite edge is not itself split in two halfeves)
-// When this predicate is called to test (prev,e), e is the primary edge but since it is  pass as e1, primary_is_0=false.
+// (so this predicate answers half the question, at one side).
+// If the split point is exactly over any of these bisectors then the split point occurs exactly and one (or both) endpoints
+// of the opposite edge (so it is a pseudo-split event since the opposite edge is not itself split in two halfedges).
+// When this predicate is called to test (prev,e), e is the primary edge but since it is passed as e1, primary_is_0=false.
 // This causes the case of parallel but not collinear edges to return positive when the split point is before the source point of e*
 // (a positive result means invalid split).
 // Likewise, primary_is_0 must be true when testing (e,nexte) to return negative if the split point is past the target endpoint of e*.
-// (in the other cases there is no need to discrminate which is 'e' in the call since the edjes do not overlap).
+// (in the other cases there is no need to discriminate which is 'e' in the call since the edges do not overlap).
 //
 // An edge event is a collision of three *consecutive* edges, say, e1,e2 and e3.
 // The collision causes e2 (the edge in the middle) to collapse and e1,e3 to become consecutive and form a new vertex.
 // In all cases there is an edge before e1, say e0, and after e3, say e4.
 // Testing for the validity of an edge event amounts to determine that (e1,e3) (the new vertex) is not before (e0,e1) nor
 // past (e3,e4).
-// Thus, and edge event is valid if the new vertex NOT to the positive side of [e0,e1] *and* NOT to the negative side o [e3,e4].
+// Thus, and edge event is valid if the new vertex is NOT to the positive side of [e0,e1] *and* NOT to the negative side of [e3,e4].
 //
 // PRECONDITIONS:
 //   There exists a single point 'p' corresponding to the event as given by the trisegment
-//   e0 and e1 are known to be consectuve at the time of the event (even if they are not consecutive in the input polygon)
-//   If e0 and e1 are not consecutive in the input, v01_event is the event that defined they very first offset vertex.
-//   If e0 and e1 are consecutive, v01_event is null.
+//   e0 and e1 are known to be consecutive at the time of the event (even if they are not consecutive in the input polygon)
+//   If e0 and e1 are not consecutive in the input, v01_event is the event that defined their first common offset vertex.
+//   If e0 and e1 are consecutive in the input, v01_event is null.
 //
-template<class K, class CoeffCache>
+template<class K, class Caches>
 Uncertain<Oriented_side>
-oriented_side_of_event_point_wrt_bisectorC2 ( boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& event,
+oriented_side_of_event_point_wrt_bisectorC2 ( Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& event,
                                               Segment_2_with_ID<K> const& e0,
+                                              typename K::FT const& w0,
                                               Segment_2_with_ID<K> const& e1,
-                                              boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& v01_event, // can be null
+                                              typename K::FT const& w1,
+                                              Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& v01_event, // can be null
                                               bool primary_is_0,
-                                              CoeffCache& aCoeff_cache )
+                                              Caches& aCaches )
 {
   typedef typename K::FT FT ;
 
-  typedef Point_2     <K> Point_2 ;
-  typedef Line_2      <K> Line_2 ;
+  typedef typename K::Point_2 Point_2 ;
+  typedef typename K::Line_2  Line_2 ;
 
   Uncertain<Oriented_side> rResult = Uncertain<Oriented_side>::indeterminate();
 
   try
   {
-    Point_2 p = validate(construct_offset_lines_isecC2(event, aCoeff_cache));
+    Point_2 p = validate(construct_offset_lines_isecC2(event, aCaches));
 
-    Line_2 l0 = validate(compute_normalized_line_ceoffC2(e0, aCoeff_cache)) ;
-    Line_2 l1 = validate(compute_normalized_line_ceoffC2(e1, aCoeff_cache)) ;
+    Line_2 l0 = validate(compute_weighted_line_coeffC2(e0, w0, aCaches));
+    Line_2 l1 = validate(compute_weighted_line_coeffC2(e1, w1, aCaches));
 
-    CGAL_STSKEL_TRAITS_TRACE("Getting oriented side of point " << p2str(p)
-                            << " w.r.t bisector ["
+    CGAL_STSKEL_TRAITS_TRACE("\n~~ Oriented side of point [" << typeid(FT).name() << "]" );
+    CGAL_STSKEL_TRAITS_TRACE("p = " << p2str(p)
+                            << " w.r.t. bisector of [E" << e0.id() << " "
                             << s2str(e0) << ( primary_is_0 ? "*" : "" )
-                            << ","
+                            << ", E" << e1.id() << " "
                             << s2str(e1) << ( primary_is_0 ? "" : "*" )
                             << "]"
                             ) ;
@@ -429,15 +390,17 @@ oriented_side_of_event_point_wrt_bisectorC2 ( boost::intrusive_ptr< Trisegment_2
       // We need to compute the actual bisector line.
       CGAL_assertion( v01_event || ( !v01_event && e0.target() == e1.source() ) ) ;
 
-      Point_2 v01 = v01_event ? validate( construct_offset_lines_isecC2(v01_event, aCoeff_cache) ) : e1.source() ;
+      Point_2 v01 = v01_event ? validate(construct_offset_lines_isecC2(v01_event, aCaches))
+                              : e1.source() ;
 
-      CGAL_STSKEL_TRAITS_TRACE("v01=" << p2str(v01) << ( v01_event ? " (from skelton node)" : "" ) ) ;
+      CGAL_STSKEL_TRAITS_TRACE("v01=" << p2str(v01) << ( v01_event ? " (from skeleton node)" : "" ) ) ;
 
-      // (a,b,c) is a line perpedincular to the primary edge through v01.
+      // (a,b,c) is a line perpendicular to the primary edge through v01.
       // If e0 and e1 are collinear this line is the actual perpendicular bisector.
       //
-      // If e0 and e1 are parallel but not collinear (then neccesarrily facing each other) this line
-      // is NOT the bisector, but the serves to determine the side of the point (projected along the primary ege) w.r.t vertex v01.
+      // If e0 and e1 are parallel but not collinear (then necessarily facing each other) this line
+      // is NOT the bisector, but it serves to determine the side of the point (projected along
+      // the primary edge) w.r.t. vertex v01.
 
       FT a, b, c ;
       perpendicular_through_pointC2( primary_is_0 ? l0.a() : l1.a()
@@ -456,13 +419,14 @@ oriented_side_of_event_point_wrt_bisectorC2 ( boost::intrusive_ptr< Trisegment_2
       FT sd_p_l0 = validate(l0.a() * p.x() + l0.b() * p.y() + l0.c()) ;
       FT sd_p_l1 = validate(l1.a() * p.x() + l1.b() * p.y() + l1.c()) ;
 
-      CGAL_STSKEL_TRAITS_TRACE("sd_p_l1=" << n2str(sd_p_l1) ) ;
-      CGAL_STSKEL_TRAITS_TRACE("sd_p_l0=" << n2str(sd_p_l0) ) ;
+      CGAL_STSKEL_TRAITS_TRACE("sd_p_l0 = " << n2str(sd_p_l0) ) ;
+      CGAL_STSKEL_TRAITS_TRACE("sd_p_l1 = " << n2str(sd_p_l1) ) ;
 
-      Uncertain<bool> equal = CGAL_NTS certified_is_equal(sd_p_l0,sd_p_l1) ;
-      if ( is_certain(equal) )
+      Uncertain<Comparison_result> lCmpResult = CGAL_NTS certified_compare(sd_p_l0,sd_p_l1) ;
+      if ( is_certain(lCmpResult) )
       {
-        if ( equal )
+        CGAL_STSKEL_TRAITS_TRACE("compare(sd_p_l0, sd_p_l1) = " << lCmpResult ) ;
+        if ( lCmpResult == EQUAL )
         {
           CGAL_STSKEL_TRAITS_TRACE("Point is exactly at bisector");
 
@@ -476,17 +440,13 @@ oriented_side_of_event_point_wrt_bisectorC2 ( boost::intrusive_ptr< Trisegment_2
             // Reflex bisector?
             if ( smaller )
             {
-              rResult = CGAL_NTS certified_is_smaller(sd_p_l0,sd_p_l1) ? ON_NEGATIVE_SIDE
-                                                                       : ON_POSITIVE_SIDE ;
-
-              CGAL_STSKEL_TRAITS_TRACE("\nEvent point is at " << rResult << " side of reflex bisector" ) ;
+              rResult = (lCmpResult == SMALLER) ? ON_NEGATIVE_SIDE : ON_POSITIVE_SIDE ;
+              CGAL_STSKEL_TRAITS_TRACE("Event point is on " << ((rResult > 0) ? "POSITIVE" : "NEGATIVE") << " side of reflex bisector" ) ;
             }
             else
             {
-              rResult = CGAL_NTS certified_is_larger (sd_p_l0,sd_p_l1) ? ON_NEGATIVE_SIDE
-                                                                       : ON_POSITIVE_SIDE ;
-
-              CGAL_STSKEL_TRAITS_TRACE("\nEvent point is at " << rResult << " side of convex bisector" ) ;
+              rResult = (lCmpResult == LARGER) ? ON_NEGATIVE_SIDE : ON_POSITIVE_SIDE ;
+              CGAL_STSKEL_TRAITS_TRACE("Event point is on " << ((rResult > 0) ? "POSITIVE" : "NEGATIVE") << " side of convex bisector" ) ;
             }
           }
         }
@@ -514,26 +474,25 @@ oriented_side_of_event_point_wrt_bisectorC2 ( boost::intrusive_ptr< Trisegment_2
 // PRECONDITIONS:
 //   There exists single points at which the offset lines for 'l' and 'r' at 'tl', 'tr' intersect.
 //
-template<class K, class TimeCache, class CoeffCache>
-Uncertain<bool> are_events_simultaneousC2 ( boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& l,
-                                            boost::intrusive_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& r,
-                                            TimeCache& aTime_cache,
-                                            CoeffCache& aCoeff_cache )
+template<class K, class Caches>
+Uncertain<bool> are_events_simultaneousC2 ( Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& l,
+                                            Trisegment_2_ptr< Trisegment_2<K, Segment_2_with_ID<K> > > const& r,
+                                            Caches& aCaches )
 {
   typedef typename K::FT FT ;
 
-  typedef Point_2<K> Point_2 ;
+  typedef typename K::Point_2 Point_2 ;
 
   typedef Rational<FT> Rational ;
   typedef Quotient<FT> Quotient ;
 
-  typedef boost::optional<Rational> Optional_rational ;
-  typedef boost::optional<Point_2>  Optional_point_2 ;
+  typedef std::optional<Rational> Optional_rational ;
+  typedef std::optional<Point_2>  Optional_point_2 ;
 
   Uncertain<bool> rResult = Uncertain<bool>::indeterminate();
 
-  Optional_rational lt_ = compute_offset_lines_isec_timeC2(l, aTime_cache, aCoeff_cache);
-  Optional_rational rt_ = compute_offset_lines_isec_timeC2(r, aTime_cache, aCoeff_cache);
+  Optional_rational lt_ = compute_offset_lines_isec_timeC2(l, aCaches);
+  Optional_rational rt_ = compute_offset_lines_isec_timeC2(r, aCaches);
 
   if ( lt_ && rt_ )
   {
@@ -548,8 +507,8 @@ Uncertain<bool> are_events_simultaneousC2 ( boost::intrusive_ptr< Trisegment_2<K
       {
         if ( equal_times )
         {
-          Optional_point_2 li = construct_offset_lines_isecC2(l, aCoeff_cache);
-          Optional_point_2 ri = construct_offset_lines_isecC2(r, aCoeff_cache);
+          Optional_point_2 li = construct_offset_lines_isecC2(l, aCaches);
+          Optional_point_2 ri = construct_offset_lines_isecC2(r, aCaches);
 
           if ( li && ri )
             rResult = CGAL_NTS logical_and( CGAL_NTS certified_is_equal(li->x(),ri->x())
